package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@$!`0D```````````(``P`!````B)4$"#0````LNP```````#0`(``&
M`"@`%P`6``8````T````-(`$"#2`!`C`````P`````4````$`````P```/0`
M``#T@`0(](`$"!4````5````!`````$````!``````````"`!`@`@`0(!;<`
M``6W```%`````!````$````(MP``"$<%"`A'!0@$`@``K`8```8`````$```
M`@```"RW```L1P4(+$<%"-@```#8````!@````0````$````#`$```R!!`@,
M@00(&````!@````$````!````"]L:6)E>&5C+VQD+65L9BYS;RXQ``````@`
M```$`````0```$9R965"4T0`8#<)`&$```!G````````````````````+0``
M``````!:````60```$<``````````````&``````````4P````@`````````
M.0```$4````\````#P```#@```!-````1````&$````````````````````O
M````5P```#<````"`````````"0```!"````.P```%X```!*````!0```&4`
M``!&````'`````````!,````8@```%$`````````,````%T`````````3@``
M`"<```!<````4````!<```!!````6P```"4`````````,0```&,`````````
M*@```"X`````````2P```"$```````````````````!F````9````#8```!6
M````&````!\```````````````````!5````-0```$,```!4````6`````X`
M````````$0````0````````````````````Z`````````"`````6````````
M`$````!?````````````````````````````````````````````````````
M````````````````````````````````"P``````````````````````````
M````````````````````#````````````````````!(````#````&@``````
M```````````````````4````$````!D````!````"@`````````>````````
M```````````````````````)```````````````````````````````5````
M```````````R````````````````````*```````````````#0``````````
M`````````#X`````````/P``````````````/0`````````L`````````!T`
M``!)````!P`````````S`````````"L````T`````````"(`````````*0``
M`$\````&````$P```````````````````%(`````````)@``````````````
M`````",```!(````&P``````````````````````````````N@,``"1'!0@$
M````$0`-``P`````````)0```!(````7`````````'`'```2````*0```"!)
M!0@!````$0`4`,X#``!PG`0(-0$``!(`"@!````````````````2````2```
M`"Q'!0@`````$0#Q_U$``````````````!(```!8`````````%(#```2````
M9@``````````````$@```&T`````````N````!(```!Y```````````````2
M````@@``````````````$@```(D`````````,@$``!(```#;`P``R)D$"`D`
M```2``H`Z`(````````C````$@```)H````D204(!````!$`%`"D````````
M`-@&```2````LP```"A)!0@$````$0`4`+T``````````````!(```##````
M`````&X````2````[`,``*B=!`@Z````$@`*`,L`````````U`(``!(```#Z
M`P``G)L$"-,````2``H`V0`````````R````$@```-\````L204(`0```!$`
M%``K!```Q)$$"``````2``@`[`````````!:!0``$@```/<`````````F0``
M`!(````$`0```````#0!```2````$@$``+!-!0@$````$0`4`!H!````````
MC`(``!(````E`0`````````````@````!@0``-29!`B'`0``$@`*`#T!````
M````$@```!(````3!```N-($"*X"```2``H`*00``+26!`@<````$@`*`%D#
M```(1P4(!````!$`#0"(`P``B)4$")$````2``H`3`$`````````````$@``
M`%(!````````;P```!(```!9`0```````!<````2````80$`````````````
M$@```&8!````````?@```!(```!R`0`````````````2````,P,````````U
M````$@```'H!`````````````!(````Q!```9,8$"!4*```2``H`@0$`````
M```F````$@```(D!````````^P,``!(```"2`0``,$D%"`0````1`!0`9`,`
M```````J````$@```#X$``"8T00(6````!(`"@"E`0``-$D%"`$````1`!0`
M.P,```````!,````$@```+,!``#XDP0(.P,``!(```##`0``.$D%"`0````1
M`!0`@P,```Q)!0@`````$`#Q_],!`````````````!(```!*!```E-4$"-<!
M```2``H`:P,````````%````$@```$\$``"`Q00(X0```!(`"@!A!```0)D$
M"(4````2``H`V@$````````B````$@```.(!```\204(`0```!$`%`#M`0``
M```````````2````Q@0````````>````$@```/0!``"0UP0(`````!(`"P#Z
M`0```````$P;```2````"`(```````"E````$@```'4#````````*P```!(`
M```0`@```````#<````2````30$`````````````$@```'<$```@1P4(!```
M`!$`#0`@`@```````#,````2````*P(`````````````$@```'P#```,204(
M`````!``\?\R`@``&$@%"``````1`/'_CP,``+1-!0@`````$`#Q_T@"```]
M204(`0```!$`%`!3`@``0$D%"!,````1`!0`BP0``)C2!`@=````$@`*`'<#
M````````1````!(```!B`@```````&D````2````IP0``%R;!`@^````$@`*
M`'D"``!4204(!````!$`%`"T!```_,0$""8````2``H`?P(``%A)!0@$````
M$0`4`(H"````````9`(``!(```"8`@``7$D%"`0````1`!0`I0(`````````
M````$@```*H"````````4````!(```"Q`@```````+T````2````N@(`````
M````````(````,X"````````+0```!(```#<`@```````$0````2````[P(`
M````````````$@```/4"`````````````"`````+`P```````#0````2````
M%0,`````````````$@```+\#``#`V@0(ZEL``!$`#``0`P```````",````2
M`````&QI8G!E<FPN<V\`4&5R;%]C<F]A:P!097)L7W-V7S)P=E]F;&%G<P!0
M3%]P97)L7V1E<W1R=6-T7VQE=F5L`&UE;6UO=F4`7T193D%-24,`9V5T<&ED
M`%!E<FQ?879?<VAI9G0`;65M8W!Y`%!E<FQ?;6=?<V5T`')E861L:6YK`&=E
M='5I9`!097)L7VYE=UA37V9L86=S`%!,7V-O;7!C=@!P97)L7V-O;G-T<G5C
M=`!03%]P87)S97(`<FUD:7(`<F5A9&1I<@!097)L7V1O=6YW:6YD`&QS965K
M`%!,7V1O7W5N9'5M<`!P97)L7W!A<G-E`%!E<FQ?;F5W4U9P=@!097)L7W-V
M7W-E='!V`&5N=FER;VX`4&5R;%]N97=84P!?7V1E<F5G:7-T97)?9G)A;65?
M:6YF;P!097)L7W-Y<U]I;FET,P!L<W1A=`!S=')S='(`7U]E<G)O<@!R96%D
M`%]?7W)U;F5T>7!E`'-T<FYC;7``=6YL:6YK`')E86QL;V,`<&5R;%]R=6X`
M7T-U<G)E;G12=6YE3&]C86QE`%!,7V5X:71?9FQA9W,`8F]O=%]$>6YA3&]A
M9&5R`%!,7V-U<G-T86-K:6YF;P!M96US970`;W!E;F1I<@!03%]T86EN=&5D
M`'-T<F-M<`!?9FEN:0!P97)L7V1E<W1R=6-T`'-P<FEN=&8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?86QL;V,`86-C97-S`%]'3$]"04Q?3T9&4T547U1!0DQ%
M7P!03%]I;E]E=F%L`%!,7VUE;6]R>5]W<F%P`%!E<FQ?<V%V95]D97-T<G5C
M=&]R7W@`4$Q?;W``4$Q?=&]P7V5N=@!097)L7V%V7V9E=&-H`%!,7V5V86Q?
M<F]O=`!O<&5N`&5X96-V<`!C;&]S961I<@!?2G9?4F5G:7-T97)#;&%S<V5S
M`%!E<FQ?<WES7W1E<FT`4&5R;%]S869E<WES;6%L;&]C`&UK9&ER`%]?<F5G
M:7-T97)?9G)A;65?:6YF;P!P97)L7V9R964`8VQO<V4`;&EB;2YS;RXT`&QI
M8F-R>7!T+G-O+C,`<W1R;F-P>0!S=')D=7``;&EB=71I;"YS;RXU`&QI8F,N
M<V\N-@!?7W!R;V=N86UE`'-T<G1O:P!?:6YI=%]T;',`871E>&ET`%]E9&%T
M80!?7V)S<U]S=&%R=`!?96YD`"]U<W(O;&]C86PO;&EB+W!E<FPU+S4N,3`N
M,2]M86-H+T-/4D4`;F%M95]L;V%D7VUY7W!A<E]P;`!P87)?:6YI=%]E;G8`
M<&%R7V-U<G)E;G1?97AE8P!P87)?96YV7V-L96%N`'!A<E]D:7)N86UE`'!A
M<E]F:6YD<')O9P!84U]);G1E<FYA;'-?4$%27T)/3U0`>'-?:6YI=`!P87)?
M;6MT;7!D:7(`<&%R7V-L96%N=7``;6%I;@!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`<VEZ95]L;V%D7VUY7W!A<E]P;`!84U])
M;G1E<FYA;'-?4$%27T-,14%24U1!0TL`<&%R7V)A<V5N86UE`&=E=%]U<V5R
M;F%M95]F<F]M7V=E='!W=6ED```@204(!00``"1)!0@%$0``*$D%"`43```L
M204(!1H``#!)!0@%,P``-$D%"`4V```X204(!3D``#Q)!0@%00``/4D%"`50
M``!`204(!5$``%1)!0@%5@``6$D%"`58``!<204(!5H``"1(!0@'`@``*$@%
M"`<#```L2`4(!P8``#!(!0@'"```-$@%"`<)```X2`4(!PH``#Q(!0@'"P``
M0$@%"`<,``!$2`4(!PT``$A(!0@'#@``3$@%"`<0``!02`4(!Q(``%1(!0@'
M%```6$@%"`<5``!<2`4(!Q<``&!(!0@'&0``9$@%"`<<``!H2`4(!QT``&Q(
M!0@''@``<$@%"`<@``!T2`4(!R,``'A(!0@'*```?$@%"`<I``"`2`4(!RH`
M`(1(!0@'*P``B$@%"`<L``",2`4(!RT``)!(!0@'+@``E$@%"`<O``"82`4(
M!S$``)Q(!0@',@``H$@%"`<T``"D2`4(!S<``*A(!0@'.```K$@%"`<[``"P
M2`4(!ST``+1(!0@'0```N$@%"`="``"\2`4(!T,``,!(!0@'10``Q$@%"`=&
M``#(2`4(!T<``,Q(!0@'2```T$@%"`=)``#42`4(!TL``-A(!0@'3```W$@%
M"`=3``#@2`4(!U0``.1(!0@'60``Z$@%"`=;``#L2`4(!UP``/!(!0@'70``
M]$@%"`=?``#X2`4(!V```/Q(!0@'80```$D%"`=C```$204(!V0```A)!0@'
M9@``@^P,Z)P$``#HFT4``(/$#,,```#_-1Q(!0C_)2!(!0@`````_R4D2`4(
M:`````#IX/____\E*$@%"&@(````Z=#_____)2Q(!0AH$````.G`_____R4P
M2`4(:!@```#IL/____\E-$@%"&@@````Z:#_____)3A(!0AH*````.F0____
M_R4\2`4(:#````#I@/____\E0$@%"&@X````Z7#_____)41(!0AH0````.E@
M_____R5(2`4(:$@```#I4/____\E3$@%"&A0````Z4#_____)5!(!0AH6```
M`.DP_____R542`4(:&````#I(/____\E6$@%"&AH````Z1#_____)5Q(!0AH
M<````.D`_____R5@2`4(:'@```#I\/[___\E9$@%"&B`````Z>#^____)6A(
M!0AHB````.G0_O___R5L2`4(:)````#IP/[___\E<$@%"&B8````Z;#^____
M)71(!0AHH````.F@_O___R5X2`4(:*@```#ID/[___\E?$@%"&BP````Z8#^
M____)8!(!0AHN````.EP_O___R6$2`4(:,````#I8/[___\EB$@%"&C(````
MZ5#^____)8Q(!0AHT````.E`_O___R602`4(:-@```#I,/[___\EE$@%"&C@
M````Z2#^____)9A(!0AHZ````.D0_O___R6<2`4(:/````#I`/[___\EH$@%
M"&CX````Z?#]____):1(!0AH``$``.G@_?___R6H2`4(:`@!``#IT/W___\E
MK$@%"&@0`0``Z<#]____);!(!0AH&`$``.FP_?___R6T2`4(:"`!``#IH/W_
M__\EN$@%"&@H`0``Z9#]____);Q(!0AH,`$``.F`_?___R7`2`4(:#@!``#I
M</W___\EQ$@%"&A``0``Z6#]____)<A(!0AH2`$``.E0_?___R7,2`4(:%`!
M``#I0/W___\ET$@%"&A8`0``Z3#]____)=1(!0AH8`$``.D@_?___R782`4(
M:&@!``#I$/W___\EW$@%"&AP`0``Z0#]____)>!(!0AH>`$``.GP_/___R7D
M2`4(:(`!``#IX/S___\EZ$@%"&B(`0``Z=#\____)>Q(!0AHD`$``.G`_/__
M_R7P2`4(:)@!``#IL/S___\E]$@%"&B@`0``Z:#\____)?A(!0AHJ`$``.F0
M_/___R7\2`4(:+`!``#I@/S___\E`$D%"&BX`0``Z7#\____)01)!0AHP`$`
M`.E@_/___R4(204(:,@!``#I4/S__U6)Y5=64X/L#(/D\(M=!(G7C72=#(7;
MB36P304(?B2+10B%P'0=HPA'!0B)P8H!A,!T$)`\+XU1`71%B=&*`83`=?&X
M+$<%"(7`=#Z#[`Q7Z)O^__^#Q!"#[`QHD-<$".B+_O__Z-+[__]05HU%"%!3
MZ)8_``"#Q!10Z,'^__^0B=&)%0A'!0CKL^@!_O__Z\>0D)!5B>6#[`B`/6!)
M!0@`=`_K.(UV`(/`!*,01P4(_]*A$$<%"(L0A=)UZ[@`````A<!T$(/L#&@H
M1P4(Z*5I^_>#Q!#&!6!)!0@!R<.05;@`````B>6#[`B%P'05@^P(:&1)!0AH
M*$<%".AW:?OW@\00H11(!0B%P'0;N`````"%P'02@^P,:!1(!0CH56G[]X/$
M$(GVR<.0D%6)Y8/L#&CVUP0(:/B3!`AH`-@$".A*_/__R<-5B>575E.#[`R%
MP(E%\(E5['15H;!-!0B%P(E%Z'1)BT7PBA"$TG0,@/H]=`=`BA"$TG7TBUWH
MB<>+,RM]\(7V=":)]E!7_W7P5NAI_/__@\00A<!U!H`\/CUT%H/#!(LSA?9U
MWXUV`#'`C67T6UY?R<,K7>C!^P*+3>R-1#X!B1GKYY!5B>6-5?R#[`CH;O__
M_\G#58GE5U93@^P<B47L@#H]B=8/A-P````QV_R(V+G_____B??RKO?128U5
M\(M%[(E-Z.@V____A<")P@^$N0```(G'_+G_____B-CRKO?123M-Z'(6B@:(
M`D9"A,!U]C'2C67T6UZ)T%_)PXM]\(M5[(H"A,!T#8GV/#UT!T**`H3`=?4K
M5>R+3>B#[`R-1`H"4(L=L$T%".B(^O__@\00A<")!+NZ_____W2UBTWLBT7P
MBQ6P304(BQ2"B@%!A,")3>QT&SP]ZQ6(`HM%[(H(0D"$R8E%[(C(=`6`^3UU
MZ<8"/4*0B@:(`D9"A,!U]NEK____1ND>____BQVP304(,?_K!9"#PP1'BP.%
MP'7VBPV`204(A<ET0(/L"(T$O0@```!0_S6P304(Z";[__^#Q!"%P*.P304(
MNO____\/A!W___^AL$T%",=$N`0`````B7WPZ17___^-#+T`````B<B#[`R#
MP`A0QP6`204(`0```(E-Y.BJ^?__@\00A<")P[K_____#X34_O__4O]UY/\U
ML$T%"%#H"/G__X/$$(D=L$T%".N<D%6)Y5.)PU*0C57XB=CHLOW__X7`=!F+
M5?BAL$T%"(T4D(M"!(7`B0)TWH/"!.OR6%O)PY!5B>575E.!["P(``!H'-@$
M"(/L#.B_^/__@\0,4&@AV`0(C9W8^___4^CZ^O__B<:#Q!`QP(7V>$16:``$
M``"-O<CW__]74^C,^/__B<:#Q!`QP(7V>":#[`R-1@%0Z.7X__^)PX/$$#'`
MA=MT#U%65U/H@?C__\8$,P")V(UE]%M>7\G#C78`58GER>EO____C78`58GE
M5U93@>Q\!```N"W8!`B+=0CH9_W__X/L"/\U%$<%"%:)A8#[___H1OG__X/$
M$(7`=!:)\K@VV`0(Z$_]__^)\(UE]%M>7\G#_+G_____,<")]_*N@^P(]]%)
M_S481P4(B8V$^____W4,Z)/Y__^#Q!"%P(G#=+N`.`!U!;NGV00(B[V`^___
MA?]T&H/L"%/_M8#[___HQ_G__X/$$(7`#X23````,<#\N?____^)W_*N]]&A
M%$<%"(U1_XH`.$03_W44B?9*Q@0:`*$41P4(B@`X1!/_=.Z+C83[__^-1`H!
M/?\#```/CT;___^#[`Q6_S441P4(4VA;V00(C87H^___4.B)^?__@\08C86(
M^___4(V-Z/O__U'HH_G__X/$$(7`=1,/MX60^___)0#P```]`(```'00@^P(
M_S481P4(:@#I(?___X/L"&H!C87H^___4.B(^?__@\00A<!UV(V5Z/O__[@V
MV`0(Z!W\__^#[`R-A>C[__]0Z)+X___IO/[__Y!5B>564XMU"(H&A,")\W0H
MB,*A%$<%"(H`ZPF0BA&$THG+=!0XPHU+`77QBA&$THG.B<MU[XUV`%N)\%[)
MPXGV58GE5U.#[!"+70B%VW0)B@.$P(A%]W44QT4(I]D$"(UE^%M?R>DB^/__
MB?8QP/RY_____XG?\J[WT8U,&?^-4?\YVG8SH11'!0B*`#A!_W4,C78`2CG:
M=A\X`G3W.=IV%XL-%$<%".L(C78`2CG:=@>*`3@"=?60.=IT/XL-%$<%"(GV
M2CG:=@:*`3@"=/4IVHU"`C')/0`$``!W%5"-0@%04VB@204(Z$_W__^YH$D%
M"(UE^%N)R%_)PZ$41P4(BE7W.A`/A$W___^)10CI3/___Y!5B>575H/L,/R-
M?<B^V-D$"+D(````\Z5FI;A#V`0(Z'C\__^X3-@$".AN_/__N%38!`CH9/S_
M_[A=V`0(Z%K\__^X9-@$".A0_/__N'38!`CH1OS__[@MV`0(Z#S\__^X@-@$
M".@R_/__N(K8!`CH*/S__[B4V`0(Z![\__^X-M@$".@4_/__N)[8!`CH"OS_
M_[BGV`0(Z`#\__^XLM@$".@^^O__A<!T#(G"N(K8!`CH/OK__[C#V`0(Z"3Z
M__^%P'0,B<*XU=@$".@D^O__N.#8!`CH"OK__X7`="*)PK@MV`0(Z`KZ__^Z
M\-@$"+ADV`0(Z/OY__^#Q#!>7\G#N/+8!`CHVOG__X7`B<)T![B`V`0(Z\Z-
M1=F_`]D$"+D*````_(G&\Z9UOXU5X[B`V`0(Z["-=@!5B>6#[`BA'$<%"(/X
M_W0$R<.)]KB`V`0(Z([Y__\QTH7`=`R*`(3`=`8\,'0"L@&)%1Q'!0B)T,G#
MB?95B>575E.)QX'LS`(``(/'.(F%9/W__S'VC78`BP>+5P2)A5C]__^+C5C]
M___!X!C!X0B)E5S]__^!X0``_P`QVR4```#_,=()R`G:BXU8_?__BYU<_?__
M#ZS9"(F-6/W__XN-6/W__\'K"(F=7/W__X'A`/\``#';"<@)VHN-6/W__XN=
M7/W__P^LV1")C5C]___!ZQ")G5S]__\/MHU8_?__,=L)R`G:B83U:/W__XF4
M]6S]__^+E5S]__^+A5C]__\/K-`(B858_?__BXU8_?__P>H(P>`8P>$(B95<
M_?__@>$``/\`,=LE````_S'2"<@)VHN-6/W__XN=7/W__P^LV0B)C5C]__^+
MC5C]___!ZPB)G5S]__^#QPB!X0#_```QVPG("=J+C5C]__^+G5S]__\/K-D0
MB8U8_?__P>L0#[:-6/W__XF=7/W__S';"<@)VHF$]7#]__^)E/5T_?__@\8"
M@_X/#XZM_O__OA````"+C/4H_?__BX3U4/W__XN<]2S]__\QR(N4]53]__^+
MC/7X_/__,=HQR(N<]?S\__^+C/7H_/__,=HQR(N<]>S\__\QVHG!T>$/K-`?
M"<$QVXF,]6C]__^)G/5L_?__1H/^3WZ<BY5D_?__BP*+4@2)E53]__^)A5#]
M__^+G63]__^+2PB+6PR)G4S]__^)C4C]__^+E63]__^+0A"+4A2)E43]__^)
MA4#]__^+E53]__^+M5#]__^+A5#]__^+G63]__\/K-`;P>8%BTL8"<:+A4C]
M__^+6QSWT(F-./W__XN-2/W__R.%./W__R.-0/W__PG!B9T\_?__BX5D_?__
M`<X#<"`#M6C]__^!QIEY@EJ)M5C]___'A5S]__\`````BYU,_?__BX5(_?__
MBXU(_?__#ZS9`L'@'@G(B85(_?__BY5<_?__B[58_?__BX58_?__#ZS0&\'F
M!0G&BX50_?__BXU0_?__]]`CA4#]__\CC4C]__\)P0'.`[4X_?__BYU4_?__
MBX50_?__BXU0_?__`[5P_?__@<:9>8):#ZS9`L'@'HFU,/W__PG(QX4T_?__
M`````(F%4/W__XN5-/W__XNU,/W__XN%,/W__P^LT!O!Y@4)QHN%6/W__XN-
M6/W___?0(X5(_?__(XU0_?__"<$!S@.U0/W__P.U>/W__X'&F7F"6L>%3/W_
M_P````#'A53]__\`````B;4X_?__BX58_?__BXU8_?__BYU<_?__#ZS9`L'@
M'@G(QX4\_?__`````(F%6/W__XN5//W__XNU./W__XN%./W__P^LT!O!Y@4)
MQHN%,/W__XN-,/W___?0(X50_?__(XU8_?__"<$!S@.U2/W__XN%,/W__XN-
M,/W__XN=-/W__P.U@/W__X'&F7F"6@^LV0+!X!Z)M4#]__\)R,>%1/W__P``
M``")A3#]__^+E43]__^+M4#]__^+A4#]__\/K-`;P>8%"<:+A3C]__^+C3C]
M___WT".%6/W__R.-,/W__PG!`<X#M5#]__\#M8C]__^!QIEY@EJ)M4C]__^+
MA3C]__^+C3C]__^+G3S]__\/K-D"P>`>"<B)A3C]__^+E4S]__^+M4C]__^+
MA4C]__\/K-`;P>8%"<:+A4#]__^+C4#]___WT".%,/W__R.-./W__PG!`<X#
MM5C]__^+A4#]__^+C4#]__^+G43]__\#M9#]__^!QIEY@EH/K-D"P>`>B;50
M_?__"<B)A4#]__^+E53]__^+M5#]__^+A5#]__\/K-`;P>8%"<:+A4C]__^+
MC4C]___WT".%./W__R.-0/W__PG!`<X#M3#]__^+G4S]__\#M9C]__^+A4C]
M__^+C4C]__^!QIEY@EH/K-D"P>`>"<B)M5C]__^)A4C]__^+M5C]__^+A5C]
M__^+E5S]__\/K-`;P>8%"<:+A5#]__^+C5#]___WT".%0/W__R.-2/W__PG!
M`<X#M3C]__^+A5#]__^+C5#]__^+G53]__\#M:#]__^!QIEY@EH/K-D"P>`>
MB;4P_?__"<B)A5#]__^+E33]__^+M3#]__^+A3#]__\/K-`;P>8%"<:+A5C]
M__^+C5C]___WT".%2/W__R.-4/W__PG!`<X#M4#]__^+A5C]__^+C5C]__^+
MG5S]__\#M:C]__^!QIEY@EH/K-D"P>`>B;4X_?__"<B)A5C]__^+E3S]__^+
MM3C]__^+A3C]__\/K-`;P>8%"<:+A3#]__^+C3#]___WT".%4/W__R.-6/W_
M_PG!`<X#M4C]__\#M;#]__^!QIEY@EJ)M4#]__^+A3#]__^+C3#]__^+G33]
M__\/K-D"P>`>"<B)A3#]__^+E43]__^+M4#]__^+A4#]__\/K-`;P>8%"<:+
MA3C]__^+C3C]___WT".%6/W__R.-,/W__PG!`<X#M5#]__^+A3C]__^+C3C]
M__^+G3S]__\#M;C]__^!QIEY@EH/K-D"P>`>B;5(_?__"<B)A3C]__^+E4S]
M__^+M4C]__^+A4C]__\/K-`;P>8%"<:+A4#]__^+C4#]___WT".%,/W__R.-
M./W__PG!`<X#M5C]__^+G43]__\#M<#]__^+A4#]__^+C4#]__^!QIEY@EH/
MK-D"P>`>"<B)M5#]__^)A4#]__^+M5#]__^+A5#]__^+E53]__\/K-`;P>8%
M"<:+A4C]__^+C4C]___WT".%./W__R.-0/W__PG!`<X#M3#]__^+A4C]__^+
MC4C]__^+G4S]__\#M<C]__^!QIEY@EH/K-D"P>`>B;58_?__"<B)A4C]__^+
ME5S]__^+M5C]__^+A5C]__\/K-`;P>8%"<:+A5#]__^+C5#]___WT".%0/W_
M_R.-2/W__PG!`<X#M3C]__^+A5#]__^+C5#]__^+G53]__\#M=#]__^!QIEY
M@EH/K-D"P>`>B;4P_?__"<B)A5#]__^+E33]__^+M3#]__^+A3#]__\/K-`;
MP>8%"<:+A5C]__^+C5C]___WT".%2/W__R.-4/W__PG!`<X#M4#]__\#M=C]
M__^!QIEY@EJ)M3C]__^+A5C]__^+C5C]__^+G5S]__\/K-D"P>`>"<B)A5C]
M__^+E3S]__^+M3C]__^+A3C]__\/K-`;P>8%"<:+A3#]__^+C3#]___WT".%
M4/W__R.-6/W__PG!`<X#M4C]__^+A3#]__^+C3#]__^+G33]__\#M>#]__^!
MQIEY@EH/K-D"P>`>B;5`_?__"<B)A3#]__^+E43]__^+M4#]__^+A4#]__\/
MK-`;P>8%"<:+A3C]__^+C3C]___WT".%6/W__R.-,/W__PG!`<X#M5#]__^+
MG3S]__\#M>C]__^+A3C]__^+C3C]__^!QIEY@EH/K-D"P>`>"<B)M4C]__^)
MA3C]__^+M4C]__^+A4C]__^+E4S]__\/K-`;P>8%"<:+A4#]__^+C4#]___W
MT".%,/W__R.-./W__PG!`<X#M5C]__^+A4#]__^+C4#]__^+G43]__\#M?#]
M__^!QIEY@EH/K-D"P>`>B;50_?__"<B)A4#]__^+E53]__^+M5#]__^+A5#]
M__\/K-`;P>8%"<:+A4C]__^+C4C]___WT".%./W__R.-0/W__PG!`<X#M3#]
M__^+A4C]__^+C4C]__^+G4S]__\#M?C]__^!QIEY@EH/K-D"P>`>B;58_?__
M"<B)A4C]__^+E5S]__^+M5C]__^+A5C]__\/K-`;P>8%"<:+A5#]__^+C5#]
M___WT".%0/W__R.-2/W__PG!`<X#M3C]__\#M0#^__^!QIEY@EJ)M3#]__^+
MA5#]__^+C5#]__^+G53]__\/K-D"P>`>"<B)A5#]__^+C3#]__^+A3#]__^+
ME33]__\/K-`;P>$%"<&+A5C]__\SA5#]__\SA4C]__\!P0.-0/W__P.-"/[_
M_X'!H>O9;HF-./W__XN%6/W__XN-6/W__XN=7/W__P^LV0+!X!X)R(F%6/W_
M_XN5//W__XN-./W__XN%./W__P^LT!O!X04)P8GP,X58_?__,X50_?__`<$#
MC4C]__\#C1#^__^!P:'KV6Z)C4#]__^+A3#]__^+C3#]__^+G33]__\/K-D"
MP>`>"<B)A3#]__^+E43]__^+C4#]__^+A4#]__\/K-`;P>$%"<&+A3C]__\S
MA3#]__\SA5C]__\!P0.-4/W__P.-&/[__X'!H>O9;HF-2/W__XN%./W__XN-
M./W__XN=//W__P^LV0+!X!X)R(F%./W__XN53/W__XN-2/W__XN%2/W__P^L
MT!O!X04)P8N%0/W__S.%./W__S.%,/W__P'!`XU8_?__`XT@_O__@<&AZ]EN
MB8U0_?__BX5`_?__BXU`_?__BYU$_?__#ZS9`L'@'@G(B85`_?__BY54_?__
MBXU0_?__BX50_?__#ZS0&\'A!0G!BX5(_?__,X5`_?__,X4X_?__`<$#C3#]
M__\#C2C^__^!P:'KV6Z+G4S]__^)C5C]__^+A4C]__^+C4C]__\/K-D"P>`>
M"<B)A4C]__^+C5C]__^+A5C]__^+E5S]__\/K-`;P>$%"<&+A5#]__\SA4C]
M__\SA4#]__\!P0.-./W__P.-,/[__X'!H>O9;HF-,/W__XN%4/W__XN-4/W_
M_XN=5/W__P^LV0+!X!X)R(F%4/W__XN5-/W__XN-,/W__XN%,/W__P^LT!O!
MX04)P8N%6/W__S.%4/W__S.%2/W__P'!`XU`_?__`XTX_O__@<&AZ]ENB8TX
M_?__BX58_?__BXU8_?__BYU<_?__#ZS9`L'@'@G(B858_?__BY4\_?__BXTX
M_?__BX4X_?__#ZS0&\'A!0G!BX4P_?__,X58_?__,X50_?__`<$#C4C]__\#
MC4#^__^!P:'KV6Z)C4#]__^+A3#]__^+C3#]__^+G33]__\/K-D"P>`>"<B)
MA3#]__^+E43]__^+C4#]__^+A4#]__\/K-`;P>$%"<&+A3C]__\SA3#]__\S
MA5C]__\!P0.-4/W__P.-2/[__X'!H>O9;HF-2/W__XN%./W__XN-./W__XN=
M//W__P^LV0+!X!X)R(F%./W__XN53/W__XN-2/W__XN%2/W__P^LT!O!X04)
MP8N%0/W__S.%./W__S.%,/W__P'!`XU8_?__`XU0_O__@<&AZ]ENBYU$_?__
MB8U0_?__BX5`_?__BXU`_?__#ZS9`L'@'@G(B85`_?__BXU0_?__BX50_?__
MBY54_?__#ZS0&\'A!0G!BX5(_?__,X5`_?__,X4X_?__`<$#C3#]__\#C5C^
M__^!P:'KV6Z)C5C]__^+A4C]__^+C4C]__^+G4S]__\/K-D"P>`>"<B)A4C]
M__^+E5S]__^+C5C]__^+A5C]__\/K-`;P>$%"<&+A5#]__\SA4C]__\SA4#]
M__\!P0.-./W__P.-8/[__X'!H>O9;HF-,/W__XN%4/W__XN-4/W__XN=5/W_
M_P^LV0+!X!X)R(F%4/W__XN5-/W__XN-,/W__XN%,/W__P^LT!O!X04)P8N%
M6/W__S.%4/W__S.%2/W__P'!`XU`_?__`XUH_O__@<&AZ]ENB8TX_?__BX58
M_?__BXU8_?__BYU<_?__#ZS9`L'@'@G(B858_?__BY4\_?__BXTX_?__BX4X
M_?__#ZS0&\'A!0G!BX4P_?__,X58_?__,X50_?__`<$#C4C]__\#C7#^__^!
MP:'KV6Z)C4#]__^+A3#]__^+C3#]__^+G33]__\/K-D"P>`>"<B)A3#]__^+
ME43]__^+C4#]__^+A4#]__\/K-`;P>$%"<&+A3C]__\SA3#]__\SA5C]__\!
MP0.-4/W__P.->/[__X'!H>O9;HN=//W__XF-2/W__XN%./W__XN-./W__P^L
MV0+!X!X)R(F%./W__XN-2/W__XN%2/W__XN53/W__P^LT!O!X04)P8N%0/W_
M_S.%./W__S.%,/W__P'!`XU8_?__`XV`_O__@<&AZ]ENB8U0_?__BX5`_?__
MBXU`_?__BYU$_?__#ZS9`L'@'@G(B85`_?__BY54_?__BXU0_?__BX50_?__
M#ZS0&\'A!0G!BX5(_?__,X5`_?__,X4X_?__`<$#C3#]__\#C8C^__^!P:'K
MV6Z)C5C]__^+A4C]__^+C4C]__^+G4S]__\/K-D"P>`>"<B)A4C]__^+E5S]
M__^+C5C]__^+A5C]__\/K-`;P>$%"<&+A5#]__\SA4C]__\SA4#]__\!P0.-
M./W__P.-D/[__X'!H>O9;HF-,/W__XN%4/W__XN-4/W__XN=5/W__P^LV0+!
MX!X)R(F%4/W__XN5-/W__XN-,/W__XN%,/W__P^LT!O!X04)P8N%6/W__S.%
M4/W__S.%2/W__P'!`XU`_?__`XV8_O__@<&AZ]ENB8TX_?__BX58_?__BXU8
M_?__BYU<_?__#ZS9`L'@'@G(B858_?__BY4\_?__BXTX_?__BX4X_?__#ZS0
M&\'A!0G!BX4P_?__,X58_?__,X50_?__`<$#C4C]__\#C:#^__^!P:'KV6Z+
MG33]__^)C4#]__^+A3#]__^+C3#]__\/K-D"P>`>"<B)A3#]__^+E43]__^+
MM4#]__^+A4#]__\/K-`;P>8%"<:+A3#]__\+A5C]__^+C3#]__\CA3C]__\C
MC5C]__\)R`'&`[50_?__BX4X_?__BXTX_?__BYT\_?__`[6H_O__@<;<O!N/
M#ZS9`L'@'HFU2/W__PG(B84X_?__BY5,_?__B[5(_?__BX5(_?__#ZS0&\'F
M!0G&BX4X_?__"X4P_?__BXTX_?__(XTP_?__(X5`_?__"<@!Q@.U6/W__XN=
M1/W__P.UL/[__XN%0/W__XN-0/W__X'&W+P;CP^LV0+!X!X)R(FU4/W__XF%
M0/W__XN55/W__XNU4/W__XN%4/W__P^LT!O!Y@4)QHN%0/W__PN%./W__XN-
M0/W__R.%2/W__R.-./W__PG(`<8#M3#]__^+A4C]__^+C4C]__^+G4S]__\#
MM;C^__^!QMR\&X\/K-D"P>`>B;58_?__"<B)A4C]__^+E5S]__^+M5C]__^+
MA5C]__\/K-`;P>8%"<:+A4C]__\+A4#]__^+C4C]__\CC4#]__\CA5#]__\)
MR`'&`[4X_?__BYU4_?__`[7`_O__BX50_?__BXU0_?__@<;<O!N/#ZS9`L'@
M'@G(B;4P_?__B850_?__BY4T_?__B[4P_?__BX4P_?__#ZS0&\'F!0G&BX50
M_?__"X5(_?__BXU0_?__(X58_?__(XU(_?__"<@!Q@.U0/W__XN%6/W__XN-
M6/W__XN=7/W__P.UR/[__X'&W+P;CP^LV0+!X!Z)M3C]__\)R(F%6/W__XN5
M//W__XNU./W__XN%./W__P^LT!O!Y@4)QHN%6/W__PN%4/W__XN-6/W__R.-
M4/W__R.%,/W__PG(`<8#M4C]__^+G33]__\#M=#^__^+A3#]__^+C3#]__^!
MQMR\&X\/K-D"P>`>"<B-E=C^__^)M4#]__^)E2S]__^)A3#]__^+E43]__^+
MM4#]__^+A4#]__\/K-`;P>8%"<:+A3#]__\+A5C]__^+C3#]__\CA3C]__\C
MC5C]__\)R`'&BXTL_?__`[50_?__`S&!QMR\&X^#P0B)C2S]__^+A3C]__^+
MC3C]__^+G3S]__\/K-D"P>`>B;5(_?__"<B)A3C]__^+E4S]__^+M4C]__^+
MA4C]__\/K-`;P>8%"<:+A3C]__\+A3#]__^+C3C]__\CC3#]__\CA4#]__\)
MR`'&BYTL_?__`[58_?__`S.!QMR\&X^#PPB)M5#]__^)G2S]__^+A4#]__^+
MC4#]__^+G43]__\/K-D"P>`>"<B)A4#]__^+E53]__^+M5#]__^+A5#]__\/
MK-`;P>8%"<:+A4#]__\+A3C]__^+C4#]__\CA4C]__\CC3C]__\)R`'&`[4P
M_?__BX4L_?__`S"!QMR\&X^#P`B)A2S]__^+C4C]__^+A4C]__^+G4S]__\/
MK-D"P>`>B;58_?__"<B)A4C]__^+E5S]__^+M5C]__^+A5C]__\/K-`;P>8%
M"<:+A4C]__\+A4#]__^+C4C]__\CC4#]__\CA5#]__\)R`'&BY4L_?__`[4X
M_?__`S*!QMR\&X^)M3#]__^+A5#]__^+C5#]__^+G53]__\/K-D"P>`>"<B#
MP@B)A5#]__^)E2S]__^+M3#]__^+E33]__^+A3#]__\/K-`;P>8%"<:+A5#]
M__\+A4C]__^+C5#]__\CA5C]__\CC4C]__\)R`'&BXTL_?__`[5`_?__`S&!
MQMR\&X^#P0B)C2S]__^+A5C]__^+C5C]__^+G5S]__\/K-D"P>`>B;4X_?__
M"<B)A5C]__^+E3S]__^+M3C]__^+A3C]__\/K-`;P>8%"<:+A5C]__\+A5#]
M__^+C5C]__\CC5#]__\CA3#]__\)R`'&BYTL_?__`[5(_?__`S.!QMR\&X^#
MPPB)M4#]__^)G2S]__^+A3#]__^+C3#]__^+G33]__\/K-D"P>`>"<B)A3#]
M__^+E43]__^+M4#]__^+A4#]__\/K-`;P>8%"<:+A3#]__\+A5C]__^+C3#]
M__\CA3C]__\CC5C]__\)R`'&`[50_?__BX4L_?__`S"!QMR\&X^#P`B)A2S]
M__^+C3C]__^+A3C]__^+G3S]__\/K-D"P>`>B;5(_?__"<B)A3C]__^+E4S]
M__^+M4C]__^+A4C]__\/K-`;P>8%"<:+A3C]__\+A3#]__^+C3C]__\CC3#]
M__\CA4#]__\)R`'&BY4L_?__`[58_?__`S*!QMR\&X^)M5#]__^+A4#]__^+
MC4#]__^+G43]__\/K-D"P>`>"<B#P@B)A4#]__^)E2S]__^+M5#]__^+E53]
M__^+A5#]__\/K-`;P>8%"<:+A4#]__\+A3C]__^+C4#]__\CA4C]__\CC3C]
M__\)R`'&BXTL_?__`[4P_?__`S&!QMR\&X^#P0B)C2S]__^+A4C]__^+C4C]
M__^+G4S]__\/K-D"P>`>B;58_?__"<B)A4C]__^+E5S]__^+M5C]__^+A5C]
M__\/K-`;P>8%"<:+A4C]__\+A4#]__^+C4C]__\CC4#]__\CA5#]__\)R`'&
MBYTL_?__`[4X_?__`S.!QMR\&X^#PPB)M3#]__^)G2S]__^+A5#]__^+C5#]
M__^+G53]__\/K-D"P>`>"<B)A5#]__^+E33]__^+M3#]__^+A3#]__\/K-`;
MP>8%"<:+A5#]__\+A4C]__^+C5#]__\CA5C]__\CC4C]__\)R`'&`[5`_?__
MBX4L_?__`S"!QMR\&X^#P`B)A2S]__^+C5C]__^+A5C]__^+G5S]__\/K-D"
MP>`>B;4X_?__"<B)A5C]__^+E3S]__^+M3C]__^+A3C]__\/K-`;P>8%"<:+
MA5C]__\+A5#]__^+C5C]__\CC5#]__\CA3#]__\)R`'&BY4L_?__`[5(_?__
M`S*!QMR\&X^)M4#]__^+A3#]__^+C3#]__^+G33]__\/K-D"P>`>"<B#P@B)
MA3#]__^)E2S]__^+M4#]__^+E43]__^+A4#]__\/K-`;P>8%"<:+A3#]__\+
MA5C]__^+C3#]__\CA3C]__\CC5C]__\)R`'&BXTL_?__`[50_?__`S&!QMR\
M&X^#P0B)C2S]__^+A3C]__^+C3C]__^+G3S]__\/K-D"P>`>B;5(_?__"<B)
MA3C]__^+E4S]__^+M4C]__^+A4C]__\/K-`;P>8%"<:+A3C]__\+A3#]__^+
MC3C]__\CC3#]__\CA4#]__\)R`'&BYTL_?__`[58_?__`S.!QMR\&X^#PPB)
MM5#]__^)G2S]__^+A4#]__^+C4#]__^+G43]__\/K-D"P>`>"<B)A4#]__^+
ME53]__^+C5#]__^+A5#]__\/K-`;P>$%"<&+A4C]__\SA4#]__\SA3C]__\!
MP0.-,/W__XN%+/W__P,(@<'6P6+*@\`(B8U8_?__B84L_?__BXU(_?__BX5(
M_?__BYU,_?__#ZS9`L'@'@G(B85(_?__BY5<_?__BXU8_?__BX58_?__#ZS0
M&\'A!0G!B?`SA4C]__\SA4#]__\!P8N5+/W__P.-./W__P,*@<'6P6+*@\((
MB8TP_?__B94L_?__BX50_?__BXU0_?__BYU4_?__#ZS9`L'@'@G(B850_?__
MBY4T_?__BXTP_?__BX4P_?__#ZS0&\'A!0G!BX58_?__,X50_?__,X5(_?__
M`<$#C4#]__^+A2S]__\#"('!UL%BRH/`"(F-./W__XF%+/W__XN-6/W__XN%
M6/W__XN=7/W__P^LV0+!X!X)R(F%6/W__XN5//W__XN-./W__XN%./W__P^L
MT!O!X04)P8N%,/W__S.%6/W__S.%4/W__P'!BY4L_?__`XU(_?__`PJ!P=;!
M8LJ#P@B)C4#]__^)E2S]__^+A3#]__^+C3#]__^+G33]__\/K-D"P>`>"<B)
MA3#]__^+E43]__^+C4#]__^+A4#]__\/K-`;P>$%"<&+A3C]__\SA3#]__\S
MA5C]__\!P0.-4/W__XN%+/W__P,(@<'6P6+*@\`(B8U(_?__B84L_?__BXTX
M_?__BX4X_?__BYT\_?__#ZS9`L'@'@G(B84X_?__BY5,_?__BXU(_?__BX5(
M_?__#ZS0&\'A!0G!BX5`_?__,X4X_?__,X4P_?__`<&+E2S]__\#C5C]__\#
M"H'!UL%BRH/""(F-4/W__XF5+/W__XN%0/W__XN-0/W__XN=1/W__P^LV0+!
MX!X)R(F%0/W__XN55/W__XN-4/W__XN%4/W__P^LT!O!X04)P8N%2/W__S.%
M0/W__S.%./W__P'!`XTP_?__BX4L_?__`PB!P=;!8LJ#P`B)C5C]__^)A2S]
M__^+C4C]__^+A4C]__^+G4S]__\/K-D"P>`>"<B)A4C]__^+E5S]__^+C5C]
M__^+A5C]__\/K-`;P>$%"<&+A5#]__\SA4C]__\SA4#]__\!P8N5+/W__P.-
M./W__P,*@<'6P6+*@\((B8TP_?__B94L_?__BX50_?__BXU0_?__BYU4_?__
M#ZS9`L'@'@G(B850_?__BY4T_?__BXTP_?__BX4P_?__#ZS0&\'A!0G!BX58
M_?__,X50_?__,X5(_?__`<$#C4#]__^+A2S]__\#"('!UL%BRH/`"(F-./W_
M_XF%+/W__XN-6/W__XN%6/W__XN=7/W__P^LV0+!X!X)R(F%6/W__XN5//W_
M_XN-./W__XN%./W__P^LT!O!X04)P8N%,/W__S.%6/W__S.%4/W__P'!BY4L
M_?__`XU(_?__`PJ!P=;!8LJ#P@B)C4#]__^)E2S]__^+A3#]__^+C3#]__^+
MG33]__\/K-D"P>`>"<B)A3#]__^+E43]__^+C4#]__^+A4#]__\/K-`;P>$%
M"<&+A3C]__\SA3#]__\SA5C]__\!P0.-4/W__XN%+/W__P,(@<'6P6+*@\`(
MB8U(_?__B84L_?__BXTX_?__BX4X_?__BYT\_?__#ZS9`L'@'@G(B84X_?__
MBY5,_?__BXU(_?__BX5(_?__#ZS0&\'A!0G!BX5`_?__,X4X_?__,X4P_?__
M`<&+E2S]__\#C5C]__\#"H'!UL%BRH/""(F-4/W__XF5+/W__XN%0/W__XN-
M0/W__XN=1/W__P^LV0+!X!X)R(F%0/W__XN55/W__XN-4/W__XN%4/W__P^L
MT!O!X04)P8N%2/W__S.%0/W__S.%./W__P'!`XTP_?__BX4L_?__`PB!P=;!
M8LJ#P`B)C5C]__^)A2S]__^+C4C]__^+A4C]__^+G4S]__\/K-D"P>`>"<B)
MA4C]__^+E5S]__^+C5C]__^+A5C]__\/K-`;P>$%"<&+A5#]__\SA4C]__\S
MA4#]__\!P8N5+/W__P.-./W__P,*@<'6P6+*@\((B8TP_?__B94L_?__BX50
M_?__BXU0_?__BYU4_?__#ZS9`L'@'@G(B850_?__BY4T_?__BXTP_?__BX4P
M_?__#ZS0&\'A!0G!BX58_?__,X50_?__,X5(_?__`<$#C4#]__^+A2S]__\#
M"('!UL%BRH/`"(F-./W__XF%+/W__XN-6/W__XN%6/W__XN=7/W__P^LV0+!
MX!X)R(F%6/W__XN5//W__XN-./W__XN%./W__P^LT!O!X04)P8N%,/W__S.%
M6/W__S.%4/W__P'!BY4L_?__`XU(_?__`PJ!P=;!8LJ#P@B)C4#]__^)E2S]
M__^+A3#]__^+C3#]__^+G33]__\/K-D"P>`>"<B)A3#]__^+E43]__^+C4#]
M__^+A4#]__\/K-`;P>$%"<&+A3C]__\SA3#]__\SA5C]__\!P0.-4/W__XN%
M+/W__P,(@<'6P6+*@\`(B8U(_?__B84L_?__BXTX_?__BX4X_?__BYT\_?__
M#ZS9`L'@'@G(B84X_?__BY5,_?__BXU(_?__BX5(_?__#ZS0&\'A!0G!BX5`
M_?__,X4X_?__,X4P_?__`<&+E2S]__\#C5C]__\#"H'!UL%BRH/""(F-4/W_
M_XF5+/W__XN%0/W__XN-0/W__XN=1/W__P^LV0+!X!X)R(F%0/W__XN55/W_
M_XN-4/W__XN%4/W__P^LT!O!X04)P8N%2/W__S.%0/W__S.%./W__P'!`XTP
M_?__BX4L_?__`PB!P=;!8LJ)C5C]__^+A4C]__^+C4C]__^+G4S]__\/K-D"
MP>`>"<B)A4C]__^+E5S]__^+C5C]__^+A5C]__\/K-`;P>$%"<&+A5#]__\S
MA4C]__\SA4#]__\!P8N5+/W__P.-./W__P-*"('!UL%BRHN=5/W__XF-,/W_
M_XN%4/W__XN-4/W__P^LV0+!X!X)R(F%4/W__XN=9/W__XL+BUL$`8TP_?__
M$9TT_?__BX4P_?__BXUD_?__,=*)`8E1!(N59/W__XM""(M2#`&%6/W__Q&5
M7/W__XN%6/W__S'2B5$,B4$(BYUD_?__BTL0BUL4`8U0_?__$9U4_?__BXUD
M_?__BX50_?__,=*)01")412+E63]__^+0AB+4AP!A4C]__\1E4S]__^+A4C]
M__\QTHE1'(E!&(N=9/W__XM+((M;)`&-0/W__Q&=1/W__XN%0/W__XN-9/W_
M_S'2B4$@B5$D@<3,`@``6UY?R<-5B>53@^P4Z&#-__^)!"3H.,___S';@\00
MA<!T`HL8B=B+7?S)PXGV58GE5E.#[&B)PXU%F%!3Z`#.__\Q]H/$$(7`=1</
MMT6@)0#P```]`$```'03/0"@``!T#(UE^%N)\%[)PXUV`(/L"&H"4^A)S___
M@\00A<!UXKX!````Z]N-=@!5B>575E.-1<B#[$R)Q[[\V00(_+D&````\Z6+
M1<B)1;0QVX`X`'1`BT6TZ*31__^%P(G&=`6`.`!U#8M5"(M%M.B>T?__ZQ.#
M[`C_=0A0Z'3-__^#Q!"%P'050XM,G<B)3;2`.0!UP(UE]%M>7\G#BTT(B4VP
M_(M]L+G_____\JZA&$<%"(E%K(G'B<HQP+G_____\J[WT8E-K(EUO+G_____
MB??RKBE-K/?2BT6L@^P,C4P0_5'H3,S__XDT)/\U&$<%"/]U"&A;V00(4(E%
MQ.@2SO__@\0@BU7$Z5W___^-=@!5B>575E.![&R!``#\C7VXOA3:!`BY!@``
M`,>%U'[__P````#'1=@TV00(\Z7'1=P\V00(QT7@I]D$",=%Y+79!`C'1:A&
MV00(QT6L2]D$",=%L+79!`BX+=@$".B/T/__A<")QG0)@#@`#X7)`@``Z"/^
M__^%P(F%R'[__P^$G0,``(N=R'[__XH#A,!T+Y`/OM"!^O\````/AF4"``"#
M[`Q2Z&S,__^#Q!`E``4``(7`=0/&`U]#B@.$P'72BT6X,=N`.`!T+.@CT/__
MA<")QG0-Z.C]__^%P`^%,@(``(N%U'[__T.%P'4)BT2=N(`X`'74B[W4?O__
M,=N%_P^$3@(``/PQP(N]U'[__[G_____\JZ)R[]4V00(N?_____RKHG.B[W(
M?O__N?_____RKO?6*<Z_M=D$"+G_____\JXISO?3@^P,C9P>^@,``%/HS\K_
M_XF%Q'[__XD<).C!RO__B87`?O__6EG_M<A^__]H5-D$"/\U%$<%"/^UU'[_
M_VA9V00(4.AWS/__@\08:.T!``#_M<!^___H1,W__[@1V00(Z$;/__^#Q!"%
MP`^$=`$``(/L#%#HQLO__UY?4(M%"/\PZ*71__^#Q!"%P(F%S'[__P^$30$`
M`#'`_+G_____B[W,?O__\JZ)R_?3C4/_@_@$B864?O__?!Z+E<Q^__^-=`+\
MN`4```"_8MD$"(G!\Z8/A(@!``#H(]7__X7`=2&#[`AJ`/^US'[__^A?S/__
M@\00A<")A;Q^__\/A28"``"Z\-@$"+B`V`0(Z*O.__^#[`AHM=D$"%#H4<G_
M_XD$)/\U%$<%"/^UP'[__S';:&?9!`CK+9#H<\K__X,X$75&4&BUV00(0U-0
MZ"#)__^)!"3_-11'!0C_M<!^__]H==D$"/^UQ'[__^A1R___@\08:.T!``#_
MM<1^___H'LS__X/$$$!TL(/L#/^UP'[__^@ZS/__BY7$?O__N"W8!`CH%L[_
M_UC_M<1^___H)OS__XN%Q'[__XUE]%M>7\G#H3!)!0B+1)`TZ9G]__^#[`Q6
MZ&G*__^#Q!")A=1^___IM_W__XM5"(L2B97,?O__Z:/^__^#[`Q0Z-K[__^)
M-"3H.LK__XUE]%M>7\G#BW78@#X`#X2F_?__B?#H6_O__X7`=2>+M=1^__]#
MA?8/A8S]__^+=)W8@#X`#X1__?__B?#H-/O__X7`=-F#[`Q6Z.O)__^#Q!")
MA=1^___KQ8.]E'[__P1T%Z$41P4(B@"+E<Q^__\X1!/Z#X58_O__BTT(BUD$
MA=L/A$K^__\QP/RY_____XG?\JZ)RO?2C4+_@_@##X8N_O__B=\QP+G_____
M\JZ)RO?2C70:^[^&V00(N04```#SI@^%"?[__XF=S'[__^G^_?__B?:+1:@Q
MVX`X`'0SZ,',__^%P'02@^P,4.A(R?__B87(?O__@\00BX7(?O__0X7`#X4O
M_/__BT2=J(`X`'7-QX7(?O__B]D$".E2_/__:@)J_VKN4.C\Q___@\0,:@:-
MA?A^__]0_[6\?O__Z'7(__^#Q!"`O?A^__\`=0V`O?E^__]##X3^!```:@!J
M`&H`_[6\?O__Z+O'__^#Q!#'A?C^__\!(T5GQX7\_O__`````,>%`/___XFK
MS>_'A03___\`````QX4(_____MRZF,>%#/___P````#'A1#___]V5#(0QX44
M____`````,>%&/____#ATL/'A1S___\`````QX4@____`````,>%)/___P``
M``#'A2C___\`````QX4L____`````,>%</___P````")]E!H`(```(V-^'[_
M_U'_M;Q^___HF,?__X/$$(7`B86X?O__#XYJ`0``BY6X?O__C87X?O__B86L
M?O__B=")E:A^__^9#Z3"`\'@`XF%B'[__XN-(/___P&-B'[__XN=)/___XF5
MC'[__Q&=C'[__S'_.?N+M8A^__]R%'<$.?%V#H.%*/___P&#E2S___\`BX6X
M?O__F8G!B=,/K-$=P>L=BX5P____`8TH____$9TL____A<")M2#___^)O23_
M__]T;+M`````*<,[G;A^__]^!HN=N'[__U)3C97X?O__4HV$*##___]0Z)+%
M__^-A?A^__\!V(F%K'[__XN%</___P'8BXVX?O__*=F#Q!"#^$")C:A^__^)
MA7#___\/A=S^__^-A?C^___H_=#__XV=,/___^LLD%!J0/^UK'[__U/H.<7_
M_X/$$(.%K'[__T"#K:A^__]`C87X_O__Z,G0__^#O:A^__\_?\Q0_[6H?O__
M_[6L?O__4^@!Q?__BY6H?O__@\00B95P____Z6W^__^#[`S_M;Q^___H#\C_
M_XN%*/___XN=(/___XNU)/___XF%H'[__XG8BY4L____#ZSP`XF5I'[__XG"
M@^(_QH0J,/___X!"@\00@_HX#XY-`@``N$`````IT%=0C905,/___VH`4NA3
MQO__C87X_O__@\00Z"'0__^Z#@```(V],/____PQP(G1\ZN+E:1^__^+A:!^
M__\/K-`8B(5H____BY6D?O__BX6@?O__#ZS0$(B%:?___XN5I'[__XN%H'[_
M_P^LT`B(A6K___^*A:!^__^(A6O___^)V`^L\!B(A6S___^)V`^L\!"(A6W_
M__^)V`^L\`B(A6[___^(G6____^-A?C^___HC,___XN%^/[__XN5_/[__XG&
M#ZS6&(GQB<8/K-`(B(7:?O__BH7X_O__#ZS6$(B%VW[__XN%`/___XN5!/__
M_XB-V'[__XGQB<8/K-88B(W9?O__B?&)Q@^LT`B(A=Y^__^*A0#___\/K-80
MB(7??O__BX4(____BY4,____B(W<?O__B?&)Q@^LUAB(C=U^__^)\8G&#ZS0
M"(B%XG[__XJ%"/___P^LUA"(A>-^__^+A1#___^+E13___^(C>!^__^)\8G&
M#ZS6&(B-X7[__XGQB<8/K-`(B(7F?O__BH40____#ZS6$(B%YW[__XN%&/__
M_XN5'/___XB-Y'[__XGQB<8/K-88B(WE?O__B?&)Q@^LUA`/K-`(B(WH?O__
MB(7J?O__B?&*A1C___^-O7C___^(C>E^__\QVXB%ZW[__XG^4`^VA!W8?O__
M4&B2V00(5D/HNL3__X/&`H/$$(/[$W[?@^P(QD6@`&BUV00(5_\U%$<%"/^U
MP'[__VB7V00(_[7$?O__Z(;$__^#Q"#I1OG__[@X````*=!14&H`C905,/__
M_U+H!L3__X/$$.G+_?__@+WZ?O__00^%]?K__X"]^W[__T,/A>CZ__^`O?Q^
M__](#X7;^O__@+W]?O__10^%SOK__VH":O]JQO^UO'[__^B)PO__@\0,:BF-
ME?A^__]2_[6\?O__Z`+#__]96VBUV00(C8WX?O__4>E-____C78`58GE5U93
M@^Q\A<")181T!8`X`'4+C67T6UY?R<.-=@"#[`Q0Z(/#__^#Q!"%P(E%@'3B
MD(/L#/]U@.C]P?__@\00A<`/A*P```"-6`B_I]D$"+D"````_(G>\Z9TUK^F
MV00(N0,```")WO.F=,:+?80QP+G_____\JZ)RHG?N?_____RKO?2]]&#[`P!
MT5'H>,'__U/_=81HJ=D$"%")QNA'P___@\08C46(4%;H:L/__X/$$$!T$`^W
M19`E`/```#T`0```=$J#[`Q6Z%O"__^#Q!"#[`Q6Z!_$__^#Q!"#[`S_=8#H
M4<'__X/$$(7`#X54____@^P,_W6`Z)O#__]8_W6$Z"+!__^-9?1;7E_)PXGP
MZ.?^___KN9!5B>564X/L#(M="%/H\\G__U#HK<G__X/$%(G&Z._+__^%P'0?
MA=MT&X`[`'06@^P(:%39!`A6Z'3!__^#Q!`Y\'0(D(UE^%M>R<.-9?B)V%M>
MR>F,_O__58GE4X/L#*$X204(BU`$H#U)!0B(0ABA.$D%"(M0!*%4204(#[=`
M$"7_`0``9HE"&J$X204(BU@$:@!HM=D$".C#P/__B4,<H3A)!0B+4`2A7$D%
M"(E"(*$X204(BU`$H2A)!0B#Q!`QR87`=`.+2&R)2B2A.$D%"(M`!,=`*```
M``"A.$D%"(M`!,=`+`````"A.$D%"(M0!*%8204(B4(PBUW\R<.058GE@^P4
M:O_H(\#__UA::@!H\-$$".@EPO__R<.-=@!5B>575E.#[`RX9-@$",8%/$D%
M"`'H@L3__S'_A<!T"8`X,0^$6P$``.B*R?__4&H+:@%HK]D$".B3P?__@\00
MA<!T=+L!````BQ6H304(BT`,.=.+<!A]5(UV`%!J`(U#_U!6Z,?!__^#Q!"%
MP(G"#X1M`0``BP#V0`D$#X02`0``BT`,@^P(4*&L304(_S28Z.K`__^#Q!"%
MP`^%0@$``$=#BQ6H304(.=-\KXU"_SGX#X3P````5VH%:@%HM-D$".@)P?__
M@\00A<")QG0D@^P(:+;9!`B+0`S_,.ANO___BT8,BP"#Q!#V0`I`#X7>````
M5FH%:@%HL-@$".C-P/__@\00A<")QG0CN#;8!`CHAL/__X7`#X30````@^P(
M4(M&#/\PZ"2___^#Q!"X+=@$",8%/$D%"`#'!21)!0@`````Z%+#__^%P*.D
M304(#X3,````@^P(:.T!``!0Z"O!__^#Q!"%P'0.@_@1=`F#^/\/A?D```"-
M9?1;7E_)PXGV@'@!``^$H/[__^F6_O__D%!J`FH`_S+HH+W__X/$$.G=_O__
MNP$````YTP^-`____XUV`(/L#%9#Z*Z]__^#Q!`[':A-!0A\Z^GF_O__@^P,
M4.BUO?__@\00Z1'___^+%:A-!0CIO_[__^@=Q?__A<")PW0;@^P(4(M&#/\P
MZ$F^__^)'"3HL<#__^D8____@^P(H:Q-!0C_,.G__O__@^P,_S6L304(Z'OQ
M__]96Z.D304(_S6L304(BU8,BP+V0`D$=%*+0`Q0Z/Z___]0BU8,BP+V0`D$
M="V+0`Q0H:Q-!0C_,&@LV@0(Z+V\__]0_S6D304(H:Q-!0C_,&A<V@0(Z*6\
M__]J`FH`_S+HJKS__X/$#.O&@^P(:@)J`/\RZ)>\__^#Q!3KGHGV58GE@^P(
MZ$'!__^#[`QJ`&BUV00(:+79!`AHN-($"&B[V00(Z.>\___)PY!5B>564X/D
M\(/L%(U%$%"-10Q0C44(4.AXO?__@\00@#TL204(``^$40$``#'2BTT(4HU!
M!5#?+"3<!;C:!`C=!;#:!`C9R=KIW^"`#31)!0@#@\0(]L1%#X1=`0``@^P,
MC02-%````%#H-K___Z.L304(BW4,BPXQTHD,D,=`!-#9!`C'0`C`V@0(QT`,
MT]D$"+L!````BTT(@\00.<NX!````,<%J$T%"`0```!\#.LFB?:+=0RAJ$T%
M"(T,`XL4GJ&L304(B52(_$.+30@YRWSAH:A-!0B-%`&AK$T%",=$D/P`````
M@^P,H:A-!0AJ``-%"/\UK$T%"$A0:&C5!`C_-:!-!0CH1[S__X/$((7`B<,/
MA(D```"#[`S_-:!-!0CHG+W__[ATV`0(Z([`__^#Q!"%P'4HH:1-!0B%P'43
MN"W8!`CH=,#__X7`HZ1-!0AT#(/L#%#HIOK__X/$$(/L#/\UH$T%".A5OO__
MZ""^__^-9?B)V%M>R</HDKW__X7`HZ!-!0AT0H/L#%#H<+O__X/$$,8%($D%
M"`#IB?[__X/L#/\UH$T%".B#O/__B<.#Q!#I7____X/L"&A`204(:"K8!`CH
MA[K__X/L#&H!Z%V]__^058GE4U*[!$@%"*$$2`4(ZPJ-=@"#ZP3_T(L#@_C_
M=?186\G#@^P,Z(2^__^#Q`S#`````"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]I
M,S@V+65L9B]C<G1I+E,L=B`Q+C<N,38N,2`R,#`X+S$P+S`R(#`R.C4W.C(T
M(&ME;G-M:71H($5X<"`D`#H`<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?
M1'EN84QO861E<@!F:6QE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'
M3D%-10!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)
M5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?
M0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!
M4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`#$`
M4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`$Q)0E!!5$@`1%E,1%],24)2
M05)97U!!5$@`5$5-4$1)4@!435``0SI<5$5-4``O=F%R+W1M<"\`55-%4@!5
M4T523D%-10!P87(M`"5S)7,E<R5S`'!A<FP`)7,E<W1E;7`M)74E<P`E<R5S
M=&5M<"TE=2TE=25S`"YP87(`4UE35$5-`"4P,G@`)7,E<V-A8VAE+25S)7,`
M+BX`)7,O)7,`05)'5@`8`'!E<FP`26YT97)N86QS.CI005(Z.D)/3U0`+64`
M+2T```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````8V00(
M#MD$"!O9!`@1V00(%MD$"+79!`C5V`0(SM@$""C9!`@WV00(,-D$"+79!`@E
M<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN
M"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@```````````(#_
M___/00``````````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N
M;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M
M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O
M;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E
M8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I
M<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S
M92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H
M870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W
M96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@
M(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M
M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI
M8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI
M;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@
M<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O
M8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@
M8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K
M92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G
M=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M
M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@
M("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL
M="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S
M;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M
M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP
M+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@
M+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@
M("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@
M("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@
M>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H
M*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?
M05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?
M(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[
M4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@
M("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]
M"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O
M9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@
M('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H
M96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@
M<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@
M)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F
M+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@
M("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@
M<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@
M:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A
M9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@
M;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD[
M"B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@
M("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H
M;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?
M=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM0
M05)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(
M3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L
M("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D
M92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@
M("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R
M8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L
M"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U
M8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@
M("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@
M(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K
M97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE
M=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@
M("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@
M("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R
M:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F
M:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@
M7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@
M("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT[
M"B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@
M)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*
M"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@
M:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I
M<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U
M:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N
M;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H
M:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@
M=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@
M("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D
M;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER
M92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S
M=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@
M=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN
M9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S
M=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET
M:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I
M<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@
M:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@
M("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@
M*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M
M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@
M(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS
M=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB
M=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N
M9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,[
M"B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@
M("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H
M($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@
M)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2![
M"B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@
M)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@
M)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@
M("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A
M;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N
M86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!
M4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@
M<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@
M("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A
M9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E
M("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF
M="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R
M*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A
M;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D
M(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@
M("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*
M"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO
M8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@
M(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@
M("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!0
M05(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*
M"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@
M8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_
M(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@
M;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@
M("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV
M*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@
M("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@
M("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@
M("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I
M;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C
M(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2![
M"B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*
M("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]
M('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I
M"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@
M("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R
M:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E
M>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@
M1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R
M97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@
M82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES
M<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE
M('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@
M("`@(",@22!F86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,[
M"B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK
M*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU
M97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N
M86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@
M/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;
M7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A
M9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M
M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@
M("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@
M("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*
M("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@
M("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@
M("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC
M:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E
M=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H
M(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U
M=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@
M("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E
M;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I
M=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D
M8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2![
M"B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G
M(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N
M9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12([
M"B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@
M)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@
M(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]
M?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![
M>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@
M(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL
M92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I
M<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*
M"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%
M7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z
M.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@
M("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@
M("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@
M+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@
M("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X
M=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@
M("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@
M("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O
M(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U
M8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@
M"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R
M97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R
M97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U
M:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z
M.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@
M1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I
M;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#
M;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/
M.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E
M(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!A='1R:6)U
M=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A
M<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L
M:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS
M=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@
M)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O
M<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@
M('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@
M("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*
M("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@
M("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@
M("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D[
M"B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L
M(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@
M("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@
M("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@
M(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@
M-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*
M("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@
M)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H
M)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@
M("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@
M:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE
M;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L
M("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E
M;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C
M;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE
M"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M
M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@
M("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@
M("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D[
M"B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@
M(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@
M("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2![
M"B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@
M("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@
M)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F
M:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<
M;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO
M;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE
M('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE
M("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*
M?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3(*"E]?
M14Y$7U\*`'!A<BYP;``D1G)E94)31#H@<W)C+VQI8B]C<W4O:3,X-BUE;&8O
M8W)T;BY3+'8@,2XV+C$V+C$@,C`P."\Q,"\P,B`P,CHU-SHR-"!K96YS;6ET
M:"!%>'`@)`````"UV00(`````!!(!0A$V00(]-<$"/_____I6P``JC8%"```
M```!`````0````$````;`P```0```"4#```!````0@,```$```!/`P``#P``
M`)0#```,````Q)$$"`T```"0UP0(!````"2!!`@%````O(H$"`8```!,A`0(
M"@```,\$```+````$````!4``````````P```!A(!0@"````T`$``!0````1
M````%P```/2/!`@1````C(\$"!(```!H````$P````@`````````````````
M``````````````````````````````````````````````````#_____````
M`/____\``````````"Q'!0@``````````.Z1!`C^D00(#I($"!Z2!`@ND@0(
M/I($"$Z2!`A>D@0(;I($"'Z2!`B.D@0(GI($"*Z2!`B^D@0(SI($"-Z2!`CN
MD@0(_I($"`Z3!`@>DP0(+I,$"#Z3!`A.DP0(7I,$"&Z3!`A^DP0(CI,$")Z3
M!`BNDP0(OI,$",Z3!`C>DP0([I,$"/Z3!`@.E`0('I0$""Z4!`@^E`0(3I0$
M"%Z4!`ANE`0(?I0$"(Z4!`B>E`0(KI0$"+Z4!`C.E`0(WI0$".Z4!`C^E`0(
M#I4$"!Z5!`@NE00(/I4$"$Z5!`A>E00(;I4$"'Z5!`@`````````````````
M```````````D1G)E94)31#H@<W)C+VQI8B]C<W4O8V]M;6]N+V-R=&)R86YD
M+F,L=B`Q+C0N,3`N,2XR+C$@,C`P."\Q,"\P,B`P,CHU-SHR-"!K96YS;6ET
M:"!%>'`@)``D1G)E94)31#H@<W)C+VQI8B]C<W4O:3,X-BUE;&8O8W)T,2YC
M+'8@,2XQ-"XQ,BXQ(#(P,#@O,3`O,#(@,#(Z-3<Z,C0@:V5N<VUI=&@@17AP
M("0`1T-#.B`H1TY5*2`S+C0N-B!;1G)E94)31%T@,C`P-C`S,#4``$=#0SH@
M*$=.52D@,RXT+C8@6T9R965"4T1=(#(P,#8P,S`U``!'0T,Z("A'3E4I(#,N
M-"XV(%M&<F5E0E-$72`R,#`V,#,P-0``1T-#.B`H1TY5*2`S+C0N-B!;1G)E
M94)31%T@,C`P-C`S,#4``$=#0SH@*$=.52D@,RXT+C8@6T9R965"4T1=(#(P
M,#8P,S`U```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X
M=``N9FEN:0`N<F]D871A`"YD871A`"YE:%]F<F%M90`N9'EN86UI8P`N8W1O
M<G,`+F1T;W)S`"YJ8W(`+F=O=``N8G-S`"YC;VUM96YT````````````````
M``````````````````````````````````````````L````!`````@```/2`
M!`CT````%0```````````````0`````````3````!P````(````,@00(#`$`
M`!@```````````````0`````````(0````4````"````)($$""0!```H`P``
M!``````````$````!````"<````+`````@```$R$!`A,!```<`8```4````!
M````!````!`````O`````P````(```"\B@0(O`H``,\$``````````````$`
M````````-P````D````"````C(\$"(P/``!H````!``````````$````"```
M`$`````)`````@```/2/!`CT#P``T`$```0````)````!`````@```!)````
M`0````8```#$D00(Q!$``!$```````````````0`````````1`````$````&
M````V)$$"-@1``"P`P`````````````$````!````$\````!````!@```(B5
M!`B(%0``"$(`````````````!`````````!5`````0````8```"0UP0(D%<`
M``P```````````````0`````````6P````$````"````H-<$"*!7``!E7P``
M```````````@`````````&,````!`````P````A'!0@(MP``(```````````
M````!`````````!I`````0````(````H1P4(*+<```0```````````````0`
M````````<P````8````#````+$<%""RW``#8````!0`````````$````"```
M`'P````!`````P````1(!0@$N```"```````````````!`````````"#````
M`0````,````,2`4(#+@```@```````````````0`````````B@````$````#
M````%$@%"!2X```$```````````````$`````````(\````!`````P```!A(
M!0@8N```]```````````````!`````0```"4````"`````,````@204((+D`
M`)0$`````````````"``````````F0````$``````````````""Y``!H`0``
M```````````!``````````$````#``````````````"(N@``H@``````````
+`````0``````````
